# lccalib

[![PyPI - Version](https://img.shields.io/pypi/v/lccalib.svg)](https://pypi.org/project/lccalib)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lccalib.svg)](https://pypi.org/project/lccalib)

-----

## Installation

```console
pip install lccalib
```

## Usage

Have a look at the demo scripts in the `tests` subfolder. 

## Authors and acknowledgment

TBD generic statement about Lemaitre acknowledgment policy. 

